Learn R Programming

stUPscales (version 1.0.3.5)

Germany_precipitation_201112: Sample precipitation time series in Germany

Description

A 1-minute sample event for precipitation time series measured in 37 rain gauge stations distributed over the territory of Germany close to the frontier to the Grand-Duchy of Luxembourg.

Usage

data("Germany_precipitation_201112")

Arguments

Format

The format is:
An 'xts' object on 2011-12-01/2011-12-31 23:59:00 containing:
Data: num [1:44640, 1:37] NA NA NA NA NA NA NA NA NA NA ...
- attr(*, "dimnames")=List of 2
..$ : NULL
..$ : chr [1:37] "Station.1327" "Station.1964" "Station.200" "Station.2170" ...
Indexed by objects of class: [POSIXct,POSIXt] TZ:
xts Attributes:
NULL

Examples

Run this code
library(stUPscales)

data(Germany_precipitation_201112)

summary(Germany_precipitation_201112)

library(zoo)
par(mfrow = c(5, 1))
for(i in 1:ncol(Germany_precipitation_201112)){
  plot(index(Germany_precipitation_201112), Germany_precipitation_201112[,i], 
       typ="l", col="blue", xlab="Time", ylab='Precip. [mm]', 
       main=colnames(Germany_precipitation_201112[,i]))
}

Run the code above in your browser using DataLab