Learn R Programming

stUPscales (version 1.0.3.5)

Lux_precipitation: Sample precipitation time series in the Grand-Duchy of Luxembourg

Description

A 10-hour sample event for precipitation time series measured in 25 rain gauge stations distributed over the territory of the Grand-Duchy of Luxembourg.

Usage

data("Lux_precipitation")

Arguments

Format

The format is:
An 'xts' object on 2011-12-16/2011-12-16 10:00:00 containing:
Data: num [1:61, 1:25] 0 0 0 0 0.1 0.1 0.1 0.1 0.1 0.2 ...
- attr(*, "dimnames")=List of 2
..$ : NULL
..$ : chr [1:25] "Dahl" "Echternach" "Esch-Sure" "Eschdorf" ...
Indexed by objects of class: [POSIXct,POSIXt] TZ:
xts Attributes:
NULL

Examples

Run this code
data(Lux_precipitation)

library(xts)
head(event.subset.xts)
tail(event.subset.xts)

plot(event.subset.xts)

Run the code above in your browser using DataLab