Learn R Programming

stUPscales (version 1.0.3.5)

Lux_precipitation_2010_2011: Sample precipitation time series in the Grand-Duchy of Luxembourg (2-year period)

Description

A 2-year period sample for precipitation time series measured at 10-minute time step in 25 rain gauge stations distributed over the territory of the Grand-Duchy of Luxembourg.

Usage

data("Lux_precipitation_2010_2011")

Arguments

Format

The format is:
An 'xts' object on 2010-01-01/2011-12-31 23:50:00 containing:
Data: num [1:105120, 1:25] 0 0 0 0 0 0 0 0 0 0 ...
- attr(*, "dimnames")=List of 2
..$ : NULL
..$ : chr [1:25] "Dahl" "Echternach" "Esch-Sure" "Eschdorf" ...
Indexed by objects of class: [POSIXct,POSIXt] TZ:
xts Attributes:
NULL

Examples

Run this code
library(stUPscales)
data(Lux_precipitation_2010_2011)

library(xts)
head(Lux_precipitation_2010_2011)
tail(Lux_precipitation_2010_2011)

## uncomment to run (plot)
# plot(Lux_precipitation_2010_2011)

Run the code above in your browser using DataLab